pub struct SqliteBackend { /* private fields */ }Implementations
Sourceimpl SqliteBackend
impl SqliteBackend
Sourcepub fn open(path: impl AsRef<Path>) -> Result<Self, BackendError>
pub fn open(path: impl AsRef<Path>) -> Result<Self, BackendError>
Opens a connection to the SQLite database.
Uses SqliteOptions::default for SQLite pragmas and cross-process
change detection.
Errors
Returns BackendError::Open when the database cannot be opened,
SQLite pragmas cannot be applied, or the settings table cannot be
created.
Sourcepub fn open_with_options(
path: impl AsRef<Path>,
options: SqliteOptions,
) -> Result<Self, BackendError>
pub fn open_with_options( path: impl AsRef<Path>, options: SqliteOptions, ) -> Result<Self, BackendError>
Opens a connection to the SQLite database with explicit backend options.
Applies the configured SQLite pragmas, creates the settings table, and
starts the cross-process watcher when options.cross_process is true.
Errors
Returns BackendError::Open when the database cannot be opened,
SQLite pragmas cannot be applied, or the settings table cannot be
created.